#!/bin/bash -e

distro_name=$(cat /etc/lsb-release | awk -F= '/DISTRIB_ID/ { print tolower($2) }' | tr -d '"')
distro_version=$(cat /etc/lsb-release | awk -F= '/DISTRIB_RELEASE/ { print $2 }' | tr -d '"')
distro=$(echo $distro_name$distro_version | tr -d '.')

packages=("libgl1")
packages+=("libfltk1.3 libfltk-gl1.3 libfltk-images1.3")

case $distro in
    ubuntu1804)
        packages+=("libopencv-core3.2 libopencv-imgcodecs3.2 libopencv-videoio3.2 libopencv-calib3d3.2")
        ;;

    ubuntu2004)
        packages+=("libopencv-core4.2 libopencv-imgcodecs4.2 libopencv-videoio4.2 libopencv-calib3d4.2")
        ;;

    *)
        packages=()
        ;;
esac

if [[ ${#packages[@]} = 0 ]]; then
    instructions="Linux distribution '$distro_name $distro_version' is not supported"
else
    if dpkg -s ${packages[@]} > /dev/null 2>&1; then
        instructions=""
    else
        instructions="In order to run VPI demos, please execute the following commands in a terminal:

sudo apt-get update"
        for packages in "${packages[@]}"; do
            instructions="$instructions
sudo apt-get install -y $packages"
        done
    fi
fi

if [[ -z "$DISPLAY" ]]; then
    instructions="X server is required to run VPI demos"
fi

if [[ "$instructions" ]]; then
    if [[ "$DISPLAY" ]]; then
        if which zenity > /dev/null 2>&1; then
            zenity --width 800 --info --title "VPI Demos" --text="$instructions"
        elif which gxmessage > /dev/null 2>&1; then
            gxmessage -geom 800x200 -title "VPI Demos" -center -buttons "OK" -default "OK" "$instructions"
        elif which xmessage > /dev/null 2>&1; then
            xmessage -geom 800x200 -title "VPI Demos" -center -buttons "OK" -default "OK" "$instructions"
        elif which xterm > /dev/null 2>&1; then
            xterm -title "VPI Demos" -e "/bin/bash -c 'echo -e \"$instructions\n\nPress any key to close this window\"; read  -n 1'"
        else
            echo "$instructions"
        fi
    else
        echo "$instructions"
    fi
else
    $@
fi
